@@ -9,6 +9,9 @@ import hashlib
 import json
 import time
 import re
+import urlparse
+import argparse
+import configargparse
 
 import logging
 import logging.handlers
@@ -18,39 +21,18 @@ import evalidate
 import socket
 from socket import AF_INET, SOCK_STREAM, SOCK_DGRAM
 
-version='2.0.64 (director)'
+import okerrclient.taskseq 
+import okerrclient.taskproc
+import okerrclient.fs
+import okerrclient.listcmd
+import okerrclient.stdin
+import okerrclient.run
 
+import okerrclient.exceptions
 
-# TODO
-# load/save caches
-# methods (e.g. portlist)
-# --prefix
-
-
-class OkerrExc(Exception):
-    pass
-
-class OkerrLockError(OkerrExc):
-    pass
-
-class OkerrClientServer(OkerrExc):
-    pass
-    
-class OkerrKeyAuth(OkerrExc):
-    pass
-        
-class OkerrNoKey(OkerrExc):
-    pass
-        
-class OkerrNoTextID(OkerrExc):
-    pass
-    
-class OkerrBadData(OkerrExc):
-    pass
-
-class OkerrBadMethod(OkerrExc):
-    pass
+version='2.0.83 (x)'
 
+ver = version.split(' ')[0]
 
 
 def briefpage(s, sz=50):
@@ -63,17 +45,17 @@ class OkerrClient:
 
     # TODO: implement list of caches including ~/.okerr-cache.json
     cachepath = '/usr/local/etc/okerr-cache.json'
-    url_director = 'https://cp.okerr.com/api/director/{textid}'
+#    url = 'https://cp.okerr.com/'
+#    url_director = 'api/director/{textid}'
     url = None
-    url_received = None
+    url_received = 0
     textid = None
     secret = None
     log = None
     cache = None   
     prefix = None    
-    
-    
-        
+    x = dict() # special headers
+                
     cfgvars = ['secret','textid','url','keyuser','keypass','cachepath']
     
     def __init__(self,cfg=None):
@@ -87,6 +69,8 @@ class OkerrClient:
         
         self.dry_run = False 
         
+        self.surl = None # server url. None before got from director
+        
         if cfg:            
             for k in self.cfgvars:
                 if k in cfg:
@@ -96,6 +80,84 @@ class OkerrClient:
                     setattr(self,k,None)
     
     
+    def make_parser(self, parser=None):
+        cflist = ['~/.okerrclient.conf','/usr/local/etc/okerrclient.conf','/etc/okerr/okerrclient.conf','/etc/okerrclient.conf']
+
+        if parser is None:
+            parser = configargparse.ArgumentParser(description='okerr client. update/create indicators over HTTP.', 
+                formatter_class = argparse.RawDescriptionHelpFormatter, add_help=False, default_config_files = cflist)
+
+        parser.add_argument('--name',dest='defname', help="default indicator name (hostname used if not set)", default=socket.gethostname())
+        parser.add_argument('--dry',action='store_true', help="dry run (for testing). indicators will not be updated", default=False)
+        parser.add_argument('-i','--textid',metavar='TextID', dest='textid', help='project unique text id (not project name!)')
+        parser.add_argument('-S','--secret', metavar='secret', dest='secret',help='optional secret')
+        parser.add_argument('--url', metavar='url', dest='url', default="https://cp.okerr.com/", help='update url')
+        parser.add_argument('--keyuser', help='username for accessing key', default="client")
+        parser.add_argument('--keypass', help='password for accessing key', default="")
+        parser.add_argument('--tpconf', nargs='*', metavar='CODE:key=value', help='change conf for task processors, e.g. RUN:enabled=1', default=None)
+
+        return parser
+        
+    def read_config(self, filename='/etc/okerrclient.conf'):
+        parser = self.make_parser()
+        parser.add_argument('-c',dest='conf', is_config_file=True, default=filename, help='conf file name')
+        
+        args = parser.parse_known_args()
+        self.set_args(args[0])
+    
+    def set_textid(textid):
+        self.textid = textid
+        self.url = None # reset url if textid changed
+       
+    def set_secret(secret):
+        self.secret = secret
+        
+    def set_x(name, value):
+        self.x[name] = value
+       
+    def set_args(self, args):
+                
+        for argname in ['keyuser', 'keypass', 'textid', 'secret', 'url', 'defname']:
+            setattr(self, argname, getattr(args, argname, None))
+
+        for tpc in args.tpconf:
+            try:
+                (code, kv) = tpc.split(':')
+                (k,v) = kv.split('=')
+                # print("code: {} arg: {} value: {}".format(code,k,v))
+                okerrclient.taskseq.TaskSeq.tp[code].tpconfset(k,v)
+            except:
+                print("ERROR",tpc)
+                self.log.error('Can not process argument tpconf: {}'.format(tpc))
+                sys.exit(1)
+
+        if args.dry:
+            oc.dry()
+    
+    
+    def runseq(self, sequence, name=None, method=None):
+        
+        self.log.debug("runseq {}: {}".format(name, sequence))
+        
+        okerrclient.taskseq.TaskSeq.oc = self
+
+        try:
+            if name is None:
+                name = self.defname          
+                  
+            ts = okerrclient.taskseq.TaskSeq(name,sequence, method)            
+        except (okerrclient.exceptions.OkerrBadMethod, ValueError) as e:
+            # dump to console, if no such method
+            self.log.error(str(e))
+            sys.exit(1)
+        try:  
+            ts.run()               
+        except okerrclient.exceptions.OkerrExc as e:
+            self.log.error("OKERR ERROR: "+str(e))
+            return False
+        return True
+
+    
     def __str__(self):
         return ("OkerrClient object\n"
             "cache: {cachepath}\n" 
@@ -108,17 +170,24 @@ class OkerrClient:
                 secret=self.secret)    
 
     def geturl(self):
-        if self.url is None or (time.time() - self.url_received) > 300:
-            durl = self.url_director.format(textid = self.textid)
-            url = requests.get(durl)
-            if url.status_code != 200:
-                self.log.error("ERROR! status code: {} for dURL {}".format(url.status_code, durl))
+        if self.surl is None or (time.time() - self.url_received) > 300:
+            durl = urlparse.urljoin(self.url,'/api/director/{}'.format(self.textid))
+            try:
+                r = requests.get(durl)                
+            except requests.exceptions.ConnectionError as e:
+                self.log.error("ERROR! geturl connection error: {}".format(str(e)))
+                self.surl = None
+                self.url_received = 0
+                return None                        
+            if r.status_code != 200:
+                self.log.error("ERROR! status code: {} for dURL {}".format(r.status_code, durl))
                 return None
-            self.log.debug("got url {} from director {}".format(url.text, durl))
-            self.url = url.text
+
+            self.log.debug("got url {} from director {}".format(r.text.rstrip(), durl))
+            self.surl = r.text.rstrip()
             self.url_received = time.time()
-        self.log.debug("geturl: return {}".format(self.url))
-        return self.url
+        self.log.debug("geturl: return {}".format(self.surl))
+        return self.surl
 
     def dry(self,dry=True):
         self.dry_run = dry
@@ -195,7 +264,7 @@ class OkerrClient:
             raise OkerrNoTextID('No textid. Cannot get keys.')
             return None
     
-        url = self.url+'getkeyval/{}/{}'.format(self.textid,path)
+        url = urlparse.urljoin(url,'getkeyval/{}/{}'.format(self.textid,path))
 
         auth=None
                 
@@ -242,17 +311,17 @@ class OkerrClient:
         if name.startswith(':') and self.prefix is not None:
             name = self.prefix+name
 
-        r = None
-        
-        if not self.url:
-            self.log.error("cannot update, url not given!")
-            return
-        
+        r = None                
         
         url = self.geturl()
+
+        if not url:
+            self.log.error("cannot update, url not given!")
+            return
+
         if not url.endswith('/'):
             url+='/'
-    
+            
         url = url+'update'
         
         self.log.debug(u"update: {}:{} = {} ({}) url: {}".format(self.textid,name,status,details, url))
@@ -269,6 +338,11 @@ class OkerrClient:
             'details': details, 'secret': self.secret, 'method': method, 'tags': ','.join(tags),'error': error,
             'keypath': keypath, 'origkeypath': origkeypath}
 
+        # process x
+        for k, v in self.x.items():
+            xname = "x_" + k
+            payload[xname] = v
+
         if self.secret:
             secretlog="[secret]"
         else:
