@@ -39,75 +39,71 @@ class DirProc(FsTaskProcessor):
         # print("! getrec:",path)
         out = []
         
-        try:
-            rec=dict()
-            rec['path']=os.path.realpath(path)
-            rec['basename']=os.path.basename(path)
-            rec['type']="UNKNOWN"
-            rec['depth']=depth
+        rec=dict()
+        rec['path']=os.path.realpath(path)
+        rec['basename']=os.path.basename(path)
+        rec['type']="UNKNOWN"
+        rec['depth']=depth
 
-            s = os.lstat(path)
+        s = os.lstat(path)
 
-            rec['size']=s.st_size
-            rec['atime']=int(s.st_atime)
-            rec['ctime']=int(s.st_ctime)
-            rec['mtime']=int(s.st_mtime)
-            
-            now = time.time()
-            rec['aage']=int(now-s.st_atime)
-            rec['mage']=int(now-s.st_mtime)
-            rec['cage']=int(now-s.st_ctime)
+        rec['size']=s.st_size
+        rec['atime']=int(s.st_atime)
+        rec['ctime']=int(s.st_ctime)
+        rec['mtime']=int(s.st_mtime)
+        
+        now = time.time()
+        rec['aage']=int(now-s.st_atime)
+        rec['mage']=int(now-s.st_mtime)
+        rec['cage']=int(now-s.st_ctime)
+        
+
+        
+        if stat.S_ISDIR(s.st_mode):
+            rec['type']="DIR"          
+            # should we go deeper?        
             
+            if not args['maxdepth'] or int(args['maxdepth'])>depth:                
+                for basename in os.listdir(path):
+                    fullname = os.path.join(path,basename)
+                    subout = self.getrec(fullname,args,depth+1, symlinks)
+                    out.extend(subout)
+
+        elif stat.S_ISCHR(s.st_mode):
+            rec['type']="CHR"
+        elif stat.S_ISBLK(s.st_mode):
+            rec['type']="BLK"
+        elif stat.S_ISREG(s.st_mode):
+            rec['type']="REG"
+            if args['md5']:
+               rec['md5'] = hashfile(open(path,'rb'), hashlib.md5())
+            if args['sha1']:
+               rec['sha1'] = hashfile(open(path,'rb'), hashlib.sha1())
+            if args['sha256']:
+               rec['sha256'] = hashfile(open(path,'rb'), hashlib.sha256())
 
             
-            if stat.S_ISDIR(s.st_mode):
-                rec['type']="DIR"          
-                # should we go deeper?        
+        elif stat.S_ISFIFO(s.st_mode):
+            rec['type']="FIFO"
+        elif stat.S_ISLNK(s.st_mode):
+            if args['symlink']=='0':               
+                rec['type']="LNK"
+            else:
+            
+                target = os.path.realpath(path)
                 
-                if not args['maxdepth'] or int(args['maxdepth'])>depth:                
-                    for basename in os.listdir(path):
-                        fullname = os.path.join(path,basename)
-                        subout = self.getrec(fullname,args,depth+1, symlinks)
-                        out.extend(subout)
-
-            elif stat.S_ISCHR(s.st_mode):
-                rec['type']="CHR"
-            elif stat.S_ISBLK(s.st_mode):
-                rec['type']="BLK"
-            elif stat.S_ISREG(s.st_mode):
-                rec['type']="REG"
-                if args['md5']:
-                   rec['md5'] = hashfile(open(path,'rb'), hashlib.md5())
-                if args['sha1']:
-                   rec['sha1'] = hashfile(open(path,'rb'), hashlib.sha1())
-                if args['sha256']:
-                   rec['sha256'] = hashfile(open(path,'rb'), hashlib.sha256())
-
-                
-            elif stat.S_ISFIFO(s.st_mode):
-                rec['type']="FIFO"
-            elif stat.S_ISLNK(s.st_mode):
-                if args['symlink']=='0':               
-                    rec['type']="LNK"
-                else:
-                
-                    target = os.path.realpath(path)
-                    
-                    if target in symlinks:
-                        return []
-                    
-                    symlinks.append(target)
-                    return self.getrec(target ,args,depth+1, symlinks)                
+                if target in symlinks:
                     return []
-                    
-            elif stat.S_ISSOCK(s.st_mode):
-                rec['type']="SOCK"
-                                           
-            if depth>=int(args['mindepth']):
-                out.append(rec)                    
-        except (IOError, OSError, PermissionError, FileNotFoundError) as e:
-            self.ts.oc.log.error("exception:"+str(e))
-#        print("return:",path,out)
+                
+                symlinks.append(target)
+                return self.getrec(target ,args,depth+1, symlinks)                
+                return []
+                
+        elif stat.S_ISSOCK(s.st_mode):
+            rec['type']="SOCK"
+                                       
+        if depth>=int(args['mindepth']):
+            out.append(rec)                    
         return out
 
     
@@ -116,7 +112,13 @@ class DirProc(FsTaskProcessor):
         if not isinstance(data,list):
             data=[]
         if args['path']:
-            data.extend(self.getrec(args['path'],args,0))        
+            try:
+                data.extend(self.getrec(args['path'],args,0))        
+            except (IOError, OSError, PermissionError, FileNotFoundError) as e:
+                self.ts.oc.log.debug("exception:"+str(e))
+                ts.stop()
+                return None
+                    
         else:
             self.ts.oc.log.error('DIR requires path, e.g. DIR path=/var/log or DIR path=/var/log/mail.log')
         return data
