@@ -7,7 +7,7 @@ import sys
 import six
 import json
 
-from okerrclient import OkerrBadMethod, OkerrBadData
+from okerrclient.exceptions import OkerrBadMethod, OkerrBadData
 
 class ListTaskProcessor(ts.TaskProcessor):
     chapter = 'Lists and Lists of dicts'
