@@ -12,13 +12,14 @@ import time
 import six
 import sys
 import socket
+import requests
 
 import evalidate
 
 from operator import itemgetter
 
 import okerrclient
-from okerrclient import OkerrExc, OkerrNoKey, OkerrNoTextID, OkerrKeyAuth, \
+from okerrclient.exceptions import OkerrExc, OkerrNoKey, OkerrNoTextID, OkerrKeyAuth, \
     OkerrBadData, OkerrBadMethod, OkerrClientServer
 
 #
@@ -262,12 +263,12 @@ class TaskSeq():
     # TaskSeq.__init__
     #
 
-    def __init__(self,iname=None,route=None,method=None):
+    def __init__(self, iname=None, route=None,method=None):
         
         if iname is None:
-            iname='noname'
-        
-        self.iname = iname
+            self.iname = self.oc.defname
+        else:
+            self.iname = iname
                         
         self.dump = ['SEQDUMP']
         
@@ -282,7 +283,6 @@ class TaskSeq():
         self.keypath = list()
         self.origkeypath = list()
         
-     
     def initvars(self):
         pass
   
@@ -388,7 +388,7 @@ class TaskSeq():
 
 
     #
-    # taskseq.runmethod
+    # taskseq.runcmd
     #
     def runcmd(self, cmd, data, args):
         return self.tp[cmd].run(self,data,args)
@@ -407,7 +407,8 @@ class TaskSeq():
                 if k!='command':
                     arg+="{}={} ".format(k,v)    
             return "{} {}".format(r['command'],arg)
-        
+
+
         for r in self.fullroute:        
             if self.steps is not None:                
                 if self.steps == 0:                
@@ -417,9 +418,7 @@ class TaskSeq():
                         self.stop()
                 else:                     
                     self.steps -= 1
-    
-    
-       
+                                  
             self.lastcmd = self.route.pop(0)
     
             if self._stop:
@@ -639,15 +638,21 @@ class TaskTag(GenTaskProcessor):
 TaskTag('TAG',TaskSeq)
 
 
-
-
 class TaskVersion(GenTaskProcessor):
-    help = 'returns client version: "{}"'.format(okerrclient.version)
+    help = 'Ask server, if current okerrclient version is OK or ERR. (ERR = need to update)'
     def run(self,ts,data,args):
-        return okerrclient.version
-    
-TaskVersion('VERSION',TaskSeq)
-
+        product = "okerrclient"
+        url = 'http://cp.okerr.com/api/check_version/{}/{}'.format(product, okerrclient.ver)
+        try:
+            r = requests.get(url)
+            d = json.loads(r.text)
+            ts.details = d['details']
+            return d['status']
+        except Exception as e:
+            ts.details = "version check error"
+            return "ERR"
+        
+TaskVersion('VERSION', TaskSeq)
 
 
 class TaskStr(GenTaskProcessor):
